.. include:: ../../README.rst

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Tutorials

   notebooks/tutorial_loading
   notebooks/tutorial_logp_value
   notebooks/tutorial_foregrounds
   notebooks/tutorial_residuals
   notebooks/tutorial_fisher

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: API

   mflike.rst
   foreground.rst
